<?php

namespace App\Livewire;

use App\Models\Year;
use App\Models\Client;
use Livewire\Component;
use Livewire\WithPagination;

class Search extends Component
{
    // use WithPagination;

    public $find = '';
    public $yearId;
    public $years;
    public $total;
    public $actif;
    public $reste;
    public $caisse;

    protected $updatesQueryString = ['find'];

    public function mount($yearId)
    {
        $this->yearId = $yearId;
        $this->years = Year::where('id', $yearId)->get();
        $this->total = Client::where('year_id', $yearId)->count();
        $this->actif = Client::where('year_id', $yearId)->where('Status', 1)->count();
        $this->reste = $this->total - $this->actif;
        $this->caisse = $this->actif * 22500;
    }

    public function render()
    {
        $clients = Client::where('year_id', $this->yearId)
            ->where(function ($query) {
                $query->where('name', 'like', '%' . $this->find . '%')
                      ->orWhere('Jan', 'like', '%' . $this->find . '%')
                      ->orWhere('Fev', 'like', '%' . $this->find . '%')
                      ->orWhere('Mars', 'like', '%' . $this->find . '%')
                      ->orWhere('Avril', 'like', '%' . $this->find . '%')
                      ->orWhere('Mai', 'like', '%' . $this->find . '%')
                      ->orWhere('Juin', 'like', '%' . $this->find . '%')
                      ->orWhere('Juil', 'like', '%' . $this->find . '%')
                      ->orWhere('Aout', 'like', '%' . $this->find . '%')
                      ->orWhere('Sept', 'like', '%' . $this->find . '%')
                      ->orWhere('Oct', 'like', '%' . $this->find . '%')
                      ->orWhere('Nov', 'like', '%' . $this->find . '%')
                      ->orWhere('Dec', 'like', '%' . $this->find . '%');
            })
            ->paginate(8);

        return view('livewire.search', [
            'clients' => $clients,
            'years' => $this->years,
            'total' => $this->total,
            'actif' => $this->actif,
            'reste' => $this->reste,
            'caisse' => $this->caisse
        ]);
    }
}
